@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from gvm.errors import InvalidArgument, RequiredArgument
 
@@ -35,7 +22,9 @@ class GmpImportScanConfigTestMixin:
         self.gmp.import_scan_config(self.CONFIG_XML_STRING)
 
         self.connection.send.has_been_called_with(
-            "<create_config>" f"{self.CONFIG_XML_STRING}" "</create_config>"
+            f"<create_config>{self.CONFIG_XML_STRING}</create_config>".encode(
+                "utf-8"
+            )
         )
 
     def test_import_missing_scan_config_xml(self):
